==> jc-1.4.0.tar.gz: javax/imageio/spi/ImageOutputStreamSpi.h <==
// public abstract class javax.imageio.spi.ImageOutputStreamSpi

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3de402a610fa78c4 javax_imageio_spi_IIOServiceProvider
// @dep_class 10eec5fcbafe5f2d javax_imageio_spi_ImageOutputStreamSpi

// header file dependencies
// @dep_header javax_imageio_spi_IIOServiceProvider

#include "javax/imageio/spi/IIOServiceProvider.h"

#ifndef _JC_javax_imageio_spi_ImageOutputStreamSpi_H_
#define _JC_javax_imageio_spi_ImageOutputStreamSpi_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_javax_imageio_stream_ImageOutputStream$object;

// Typedefs
typedef struct _jc_javax_imageio_spi_ImageOutputStreamSpi$sub_refs	_jc_javax_imageio_spi_ImageOutputStreamSpi$sub_refs;
typedef struct _jc_javax_imageio_spi_ImageOutputStreamSpi$sub_nonrefs	_jc_javax_imageio_spi_ImageOutputStreamSpi$sub_nonrefs;
typedef struct _jc_javax_imageio_spi_ImageOutputStreamSpi$refs	_jc_javax_imageio_spi_ImageOutputStreamSpi$refs;
typedef struct _jc_javax_imageio_spi_ImageOutputStreamSpi$nonrefs	_jc_javax_imageio_spi_ImageOutputStreamSpi$nonrefs;
typedef struct _jc_javax_imageio_spi_ImageOutputStreamSpi$object	_jc_javax_imageio_spi_ImageOutputStreamSpi$object;

typedef const struct _jc_javax_imageio_spi_ImageOutputStreamSpi$vmethods	_jc_javax_imageio_spi_ImageOutputStreamSpi$vmethods;
typedef const struct _jc_javax_imageio_spi_ImageOutputStreamSpi$vtable	_jc_javax_imageio_spi_ImageOutputStreamSpi$vtable;
typedef const struct _jc_javax_imageio_spi_ImageOutputStreamSpi$vtype	_jc_javax_imageio_spi_ImageOutputStreamSpi$vtype;

// Constructors
extern void _jc_javax_imageio_spi_ImageOutputStreamSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_imageio_spi_ImageOutputStreamSpi$object *);
extern void _jc_javax_imageio_spi_ImageOutputStreamSpi$method$_init$99693247212c4336(_jc_env *, struct _jc_javax_imageio_spi_ImageOutputStreamSpi$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Class$object *);

// Virtual methods
extern jboolean _jc_javax_imageio_spi_ImageOutputStreamSpi$method$canUseCacheFile$86e50483d06c0326(_jc_env *, struct _jc_javax_imageio_spi_ImageOutputStreamSpi$object *);
extern struct _jc_object *_jc_javax_imageio_spi_ImageOutputStreamSpi$method$createOutputStreamInstance$e1b6902f110b92f0(_jc_env *, struct _jc_javax_imageio_spi_ImageOutputStreamSpi$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_object *_jc_javax_imageio_spi_ImageOutputStreamSpi$method$createOutputStreamInstance$2aaf72a081c281da(_jc_env *, struct _jc_javax_imageio_spi_ImageOutputStreamSpi$object *, struct _jc_java_lang_Object$object *, jboolean, struct _jc_java_io_File$object *);
extern struct _jc_java_lang_Class$object *_jc_javax_imageio_spi_ImageOutputStreamSpi$method$getOutputClass$689188d0db3e82fb(_jc_env *, struct _jc_javax_imageio_spi_ImageOutputStreamSpi$object *);
extern jboolean _jc_javax_imageio_spi_ImageOutputStreamSpi$method$needsCacheFile$eb3e6b64e84aa38c(_jc_env *, struct _jc_javax_imageio_spi_ImageOutputStreamSpi$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_spi_ImageOutputStreamSpi$method_info$canUseCacheFile$86e50483d06c0326;
extern _jc_method _jc_javax_imageio_spi_ImageOutputStreamSpi$method_info$createOutputStreamInstance$e1b6902f110b92f0;
extern _jc_method _jc_javax_imageio_spi_ImageOutputStreamSpi$method_info$createOutputStreamInstance$2aaf72a081c281da;
extern _jc_method _jc_javax_imageio_spi_ImageOutputStreamSpi$method_info$getOutputClass$689188d0db3e82fb;
extern _jc_method _jc_javax_imageio_spi_ImageOutputStreamSpi$method_info$needsCacheFile$eb3e6b64e84aa38c;

// Virtual methods structure
struct _jc_javax_imageio_spi_ImageOutputStreamSpi$vmethods {
	jboolean	(*canUseCacheFile$86e50483d06c0326)(_jc_env *, struct _jc_javax_imageio_spi_ImageOutputStreamSpi$object *);
	struct _jc_object	*(*createOutputStreamInstance$e1b6902f110b92f0)(_jc_env *, struct _jc_javax_imageio_spi_ImageOutputStreamSpi$object *, struct _jc_java_lang_Object$object *);
	struct _jc_object	*(*createOutputStreamInstance$2aaf72a081c281da)(_jc_env *, struct _jc_javax_imageio_spi_ImageOutputStreamSpi$object *, struct _jc_java_lang_Object$object *, jboolean, struct _jc_java_io_File$object *);
	struct _jc_java_lang_Class$object	*(*getOutputClass$689188d0db3e82fb)(_jc_env *, struct _jc_javax_imageio_spi_ImageOutputStreamSpi$object *);
	jboolean	(*needsCacheFile$eb3e6b64e84aa38c)(_jc_env *, struct _jc_javax_imageio_spi_ImageOutputStreamSpi$object *);
};

// Vtable
struct _jc_javax_imageio_spi_ImageOutputStreamSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_spi_IIOServiceProvider$vmethods	javax_imageio_spi_IIOServiceProvider;
	_jc_javax_imageio_spi_ImageOutputStreamSpi$vmethods	javax_imageio_spi_ImageOutputStreamSpi;
};

// Vtype
struct _jc_javax_imageio_spi_ImageOutputStreamSpi$vtype {
	_jc_type			type;
	_jc_javax_imageio_spi_ImageOutputStreamSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_spi_ImageOutputStreamSpi$sub_refs {
	struct _jc_java_lang_Class$object	*outputClass;
};

// Reference instance fields (object)
struct _jc_javax_imageio_spi_ImageOutputStreamSpi$refs {
    _jc_javax_imageio_spi_ImageOutputStreamSpi$sub_refs	javax_imageio_spi_ImageOutputStreamSpi;
    _jc_javax_imageio_spi_IIOServiceProvider$sub_refs	javax_imageio_spi_IIOServiceProvider;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_spi_ImageOutputStreamSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_spi_ImageOutputStreamSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_spi_IIOServiceProvider$sub_nonrefs	javax_imageio_spi_IIOServiceProvider;
    _jc_javax_imageio_spi_ImageOutputStreamSpi$sub_nonrefs	javax_imageio_spi_ImageOutputStreamSpi;
};

// Object instance structure
struct _jc_javax_imageio_spi_ImageOutputStreamSpi$object {
	_jc_javax_imageio_spi_ImageOutputStreamSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_spi_ImageOutputStreamSpi$vtype	*vtype;
	_jc_javax_imageio_spi_ImageOutputStreamSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_spi_ImageOutputStreamSpi$vtype _jc_javax_imageio_spi_ImageOutputStreamSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_spi_ImageOutputStreamSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_spi_ImageOutputStreamSpi$class_object;

#endif	/* _JC_javax_imageio_spi_ImageOutputStreamSpi_H_ */

==> jc-1.4.6.tar.gz: javax/imageio/spi/ImageOutputStreamSpi.h <==
// public abstract class javax.imageio.spi.ImageOutputStreamSpi

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3de402a610fa78c4 javax_imageio_spi_IIOServiceProvider
// @dep_class 10eec5fcbafe5f2d javax_imageio_spi_ImageOutputStreamSpi

// header file dependencies
// @dep_header javax_imageio_spi_IIOServiceProvider

#include "javax/imageio/spi/IIOServiceProvider.h"

#ifndef _JC_javax_imageio_spi_ImageOutputStreamSpi_H_
#define _JC_javax_imageio_spi_ImageOutputStreamSpi_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_javax_imageio_stream_ImageOutputStream$object;

// Typedefs
typedef struct _jc_javax_imageio_spi_ImageOutputStreamSpi$sub_refs	_jc_javax_imageio_spi_ImageOutputStreamSpi$sub_refs;
typedef struct _jc_javax_imageio_spi_ImageOutputStreamSpi$sub_nonrefs	_jc_javax_imageio_spi_ImageOutputStreamSpi$sub_nonrefs;
typedef struct _jc_javax_imageio_spi_ImageOutputStreamSpi$refs	_jc_javax_imageio_spi_ImageOutputStreamSpi$refs;
typedef struct _jc_javax_imageio_spi_ImageOutputStreamSpi$nonrefs	_jc_javax_imageio_spi_ImageOutputStreamSpi$nonrefs;
typedef struct _jc_javax_imageio_spi_ImageOutputStreamSpi$object	_jc_javax_imageio_spi_ImageOutputStreamSpi$object;

typedef const struct _jc_javax_imageio_spi_ImageOutputStreamSpi$vmethods	_jc_javax_imageio_spi_ImageOutputStreamSpi$vmethods;
typedef const struct _jc_javax_imageio_spi_ImageOutputStreamSpi$vtable	_jc_javax_imageio_spi_ImageOutputStreamSpi$vtable;
typedef const struct _jc_javax_imageio_spi_ImageOutputStreamSpi$vtype	_jc_javax_imageio_spi_ImageOutputStreamSpi$vtype;

// Constructors
extern void _jc_javax_imageio_spi_ImageOutputStreamSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_imageio_spi_ImageOutputStreamSpi$object *) _JC_JCNI_ATTR;
extern void _jc_javax_imageio_spi_ImageOutputStreamSpi$method$_init$99693247212c4336(_jc_env *, struct _jc_javax_imageio_spi_ImageOutputStreamSpi$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_imageio_spi_ImageOutputStreamSpi$method$canUseCacheFile$86e50483d06c0326(_jc_env *, struct _jc_javax_imageio_spi_ImageOutputStreamSpi$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_imageio_spi_ImageOutputStreamSpi$method$createOutputStreamInstance$e1b6902f110b92f0(_jc_env *, struct _jc_javax_imageio_spi_ImageOutputStreamSpi$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_imageio_spi_ImageOutputStreamSpi$method$createOutputStreamInstance$2aaf72a081c281da(_jc_env *, struct _jc_javax_imageio_spi_ImageOutputStreamSpi$object *, struct _jc_java_lang_Object$object *, jboolean, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_javax_imageio_spi_ImageOutputStreamSpi$method$getOutputClass$689188d0db3e82fb(_jc_env *, struct _jc_javax_imageio_spi_ImageOutputStreamSpi$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_imageio_spi_ImageOutputStreamSpi$method$needsCacheFile$eb3e6b64e84aa38c(_jc_env *, struct _jc_javax_imageio_spi_ImageOutputStreamSpi$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_spi_ImageOutputStreamSpi$method_info$canUseCacheFile$86e50483d06c0326;
extern _jc_method _jc_javax_imageio_spi_ImageOutputStreamSpi$method_info$createOutputStreamInstance$e1b6902f110b92f0;
extern _jc_method _jc_javax_imageio_spi_ImageOutputStreamSpi$method_info$createOutputStreamInstance$2aaf72a081c281da;
extern _jc_method _jc_javax_imageio_spi_ImageOutputStreamSpi$method_info$getOutputClass$689188d0db3e82fb;
extern _jc_method _jc_javax_imageio_spi_ImageOutputStreamSpi$method_info$needsCacheFile$eb3e6b64e84aa38c;

// Virtual methods structure
struct _jc_javax_imageio_spi_ImageOutputStreamSpi$vmethods {
	jboolean	(*canUseCacheFile$86e50483d06c0326)(_jc_env *, struct _jc_javax_imageio_spi_ImageOutputStreamSpi$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*createOutputStreamInstance$e1b6902f110b92f0)(_jc_env *, struct _jc_javax_imageio_spi_ImageOutputStreamSpi$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*createOutputStreamInstance$2aaf72a081c281da)(_jc_env *, struct _jc_javax_imageio_spi_ImageOutputStreamSpi$object *, struct _jc_java_lang_Object$object *, jboolean, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Class$object	*(*getOutputClass$689188d0db3e82fb)(_jc_env *, struct _jc_javax_imageio_spi_ImageOutputStreamSpi$object *) _JC_JCNI_ATTR;
	jboolean	(*needsCacheFile$eb3e6b64e84aa38c)(_jc_env *, struct _jc_javax_imageio_spi_ImageOutputStreamSpi$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_imageio_spi_ImageOutputStreamSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_spi_IIOServiceProvider$vmethods	javax_imageio_spi_IIOServiceProvider;
	_jc_javax_imageio_spi_ImageOutputStreamSpi$vmethods	javax_imageio_spi_ImageOutputStreamSpi;
};

// Vtype
struct _jc_javax_imageio_spi_ImageOutputStreamSpi$vtype {
	_jc_type			type;
	_jc_javax_imageio_spi_ImageOutputStreamSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_spi_ImageOutputStreamSpi$sub_refs {
	struct _jc_java_lang_Class$object	*outputClass;
};

// Reference instance fields (object)
struct _jc_javax_imageio_spi_ImageOutputStreamSpi$refs {
    _jc_javax_imageio_spi_ImageOutputStreamSpi$sub_refs	javax_imageio_spi_ImageOutputStreamSpi;
    _jc_javax_imageio_spi_IIOServiceProvider$sub_refs	javax_imageio_spi_IIOServiceProvider;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_spi_ImageOutputStreamSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_spi_ImageOutputStreamSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_spi_IIOServiceProvider$sub_nonrefs	javax_imageio_spi_IIOServiceProvider;
    _jc_javax_imageio_spi_ImageOutputStreamSpi$sub_nonrefs	javax_imageio_spi_ImageOutputStreamSpi;
};

// Object instance structure
struct _jc_javax_imageio_spi_ImageOutputStreamSpi$object {
	_jc_javax_imageio_spi_ImageOutputStreamSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_spi_ImageOutputStreamSpi$vtype	*vtype;
	_jc_javax_imageio_spi_ImageOutputStreamSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_spi_ImageOutputStreamSpi$vtype _jc_javax_imageio_spi_ImageOutputStreamSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_spi_ImageOutputStreamSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_spi_ImageOutputStreamSpi$class_object;

#endif	/* _JC_javax_imageio_spi_ImageOutputStreamSpi_H_ */
